summaryrefslogtreecommitdiffhomepage
diff options
context:
space:
mode:
authorPablo Mazzini <pmazzini@gmail.com>2020-03-09 18:02:01 +0000
committerGitHub <noreply@github.com>2020-03-09 18:02:01 +0000
commit6ddd6be671cd02c85f68cefefb7bbe2500e231d6 (patch)
treef43cd7d367e19192030b63ed47406ba7c8e353f8
parent430fc1644a04631f3dfc3e0d19d0dcd0916e6e1d (diff)
parent200399fb8fcb0ba141e171ed0ce3ce23758b877a (diff)
Merge branch 'master' into write16
-rwxr-xr-x.travis/tests.sh6
1 files changed, 3 insertions, 3 deletions
diff --git a/.travis/tests.sh b/.travis/tests.sh
index edf17ba..ac83700 100755
--- a/.travis/tests.sh
+++ b/.travis/tests.sh
@@ -39,9 +39,9 @@ done
# check that we are not breaking some projects that depend on us. Remove this after moving to
# Go versioned modules, see https://github.com/insomniacslk/dhcp/issues/123
-# Skip go1.9 for this check. rtr7/router7 depends on miekg/dns, which does not
-# support go1.9
-if [[ "$TRAVIS_GO_VERSION" =~ ^1.(9|10|11)$ ]]
+# Skip go1.12 for this check. rtr7/router7 depends on google/nftables, which does not
+# support go1.12
+if [[ "$TRAVIS_GO_VERSION" =~ ^1.(9|10|11|12)$ ]]
then
exit 0
fi